@@ -81,9 +81,9 @@ DEFINITION = {
     'email_smtp':[
         ('smtplib','instrument_smtp'),
     ],
-    'amqp_kombu':[
-        ('kombu','instrument_kombu'),
-    ],
+    #'amqp_kombu':[
+    #    ('kombu','instrument_kombu'),
+    #],
     'amqp_pika':[
         ('pika.channel','instrument_pika'),
     ],
